pub fn code_font_weight(cx: &App) -> Option<FontWeight>Expand description
Returns the configured default code text weight, if the app overrides it.
pub fn code_font_weight(cx: &App) -> Option<FontWeight>Returns the configured default code text weight, if the app overrides it.