pub enum FontLoadMode {
Embedded,
External,
ExternalThenEmbedded,
Mixed,
}Expand description
Controls which resource location is used when loading app fonts.
Variants
Embedded
Only load fonts that were embedded in the executable with include_bytes!.
External
Only load fonts from external filesystem directories or GPUI assets.
ExternalThenEmbedded
Prefer external mounted files/assets and fall back to embedded bytes when no external font could be registered.
Mixed
Always register both external and embedded fonts. Use this when the app intentionally ships different families in different locations.