ContextExt

Trait ContextExt 

pub trait ContextExt {
    // Required method
    fn liora(&self) -> &Theme;
}
Convenience accessors for reading Liora theme data from GPUI contexts.

Required Methods

fn liora(&self) -> &Theme

Returns the active Liora theme for the current context.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, V> ContextExt for Context<'a, V>

Source

fn liora(&self) -> &Theme

Implementors